@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "eglot-python-preset" "0.2.3"
+(define-package "eglot-python-preset" "20260108.56"
   "Eglot preset for Python."
   '((emacs "30.2")
     (eglot "1.17"))
